<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage  Sellnow
 * @since  Sellnow 1.0.0
 */

if ( ! function_exists( 'sellnow_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since  Sellnow 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function sellnow_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'sellnow_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'sellnow_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Sellnow 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function sellnow_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'sellnow_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since  Sellnow 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function sellnow_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'sellnow_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'sellnow_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since  Sellnow 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function sellnow_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'sellnow_theme_options[pagination_enable]' )->value();
	}
endif;

/*==================Banner Settings===============*/

function sellnow_is_banner_enable_on_single_page( $control ) {
	return ( $control->manager->get_setting( 'sellnow_theme_options[single_post_hide_banner]' )->value() );
}

function sellnow_is_banner_enable_on_blog_page( $control ) {
	return ( $control->manager->get_setting( 'sellnow_theme_options[hide_banner]' )->value() );
}

if ( ! function_exists( 'sellnow_is_banner_settings_enable' ) ) :
	/**
	 * Check if banner settings is enabled.
	 *
	 * @since Sellnow 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function sellnow_is_banner_settings_enable( $control ) {
		return $control->manager->get_setting( 'sellnow_theme_options[banner_settings_enable]' )->value();
	}
endif;

/*==================hero banner===============*/

/**
 * Check if popular products section is enabled.
 *
 * @since Biopexel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sellnow_is_hero_banner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sellnow_theme_options[hero_banner_section_enable]' )->value() );
}


/**
 * Check if popular_product section separator is enabled.
 *
 * @since  Biopexel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sellnow_is_hero_banner_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'sellnow_theme_options[hero_banner_content_type]' )->value();
    return sellnow_is_hero_banner_section_enable( $control ) && !( 'product-category' == $content_type );
}

/*==================partners===============*/

/**
 * Check if partners section is enabled.
 *
 * @since Sellnow 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sellnow_is_partners_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sellnow_theme_options[partners_section_enable]' )->value() );
}

/*==================popular collection===============*/

/**
 * Check if popular_collections section is enabled.
 *
 * @since Sellnow 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sellnow_is_popular_collections_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sellnow_theme_options[popular_collections_section_enable]' )->value() );
}

/*==================why choose us===============*/

/**
 * Check if service section is enabled.
 *
 * @since Biopexel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sellnow_is_why_choose_us_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sellnow_theme_options[why_choose_us_section_enable]' )->value() );
}

/*==================recent stories===============*/

/**
 * Check if most viewed posts section is enabled.
 *
 * @since Sellnow 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sellnow_is_recent_stories_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sellnow_theme_options[recent_stories_section_enable]' )->value() );
}

/*==================Subscribe===============*/

/**
 * Check if Subscribe Us section is enabled.
 *
 * @since  Biopexel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sellnow_is_subscribe_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sellnow_theme_options[subscribe_section_enable]' )->value() );
}

/*==================Latest Products===============*/

/**
 * Check if popular_product section content type is product.
 *
 * @since Fairtimes Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function sellnow_is_latest_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sellnow_theme_options[latest_products_section_enable]' )->value() );
}