<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Sellnow
 * @since  Sellnow 1.0.0
 * @return array An array of default values
 */

function sellnow_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$sellnow_default_options = array(
		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#000',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#d87b4d',
		'colorscheme'					    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',

		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',


		// excerpt options
		'long_excerpt_length'               => 25,

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// search menu items
		'enable_cart_button'                => (bool) true,
		'login_text'				        => esc_html__( 'Login', 'sellnow' ),
		'enable_login_button'               => (bool) true,

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'sellnow' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'all_sortable' 						=> 'hero_banner,latest_products,partners,popular_collections,why_choose_us,recent_stories,subscribe',

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'sellnow' ),
		'blog_column'						=> 'col-2',


		// single post theme options
		'single_post_hide_banner'		    => (bool) false,
		'single_post_hide_image'		    => (bool) false,
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,
		'hide_category'			   			=> (bool) false,
		'hide_banner' 				        => (bool) false,
		'hide_image' 				        => (bool) false,
		'hide_title' 				        => (bool) false,

		// banner settings
		'banner_settings_enable'        => (bool) true,

		/* Front Page */

		// hero banner
		'hero_banner_section_enable'	 => (bool) false,
		'hero_banner_content_type'		 => 'product',
		'hero_banner_title'				 => esc_html__( 'Best Seller Products', 'sellnow' ),
		'hero_banner_btn_title'			 => esc_html__( 'Shop', 'sellnow' ),


		// Latest Product
		'latest_products_section_enable'	   => false,


		// partners
		'partners_section_enable'	    => (bool) false,


		//popular collections
		'popular_collections_section_enable'	=> false,
		'popular_collections_content_type'		=> 'category',
		'popular_collections_count'				=> 6,
		'popular_collections_buy_now_btn'       => esc_html__( 'Buy Now', 'sellnow' ),
		'popular_collections_title'				=> esc_html__( 'Popular Collections', 'sellnow' ),
		'popular_collections_btn_title'			=> esc_html__( 'View All Products', 'sellnow' ),

		// why_choose_us
		'why_choose_us_section_enable'		   => (bool) false,
		'why_choose_us_title'                  => esc_html__('Why Choose Us','sellnow'),
		'why_choose_us_btn_title'              => esc_html__('Read More','sellnow'),

		// recent stories
		'recent_stories_title'		           => esc_html__( 'Our Recent Stories', 'sellnow' ),
		'recent_stories_section_enable'        => (bool) false,
		'recent_stories_content_type'          => 'post',
		'recent_stories_count'			       => 3,

		//subscribe
		'subscribe_section_enable' 			   => (bool) false,
		'subscribe_section_title'			   =>	esc_html__('Subscribe Now!', 'sellnow'),
		'subscribe_section_subtitle'	       =>	esc_html__('Christmas Sale', 'sellnow'),
		'subscribe_section_description'		   =>	esc_html__('Check out our best men’s collection to stay fashionable and casual this season.The best products in every category.', 'sellnow'),
		'subscribe_section_btn_txt'			   =>	esc_html__('Subscribe Now', 'sellnow'),

	);

$output = apply_filters( 'sellnow_default_theme_options', $sellnow_default_options );

	// Sort array in ascending order, according to the key:
if ( ! empty( $output ) ) {
	ksort( $output );
}

return $output;
}