<?php
/**
 * Hero Banner Section options
 *
 * @package Theme Palace
 * @subpackage Sellnow
 * @since Sellnow 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}
// Add Product section
$wp_customize->add_section( 'sellnow_hero_banner_section',
	array(
		'title'             => esc_html__( 'Hero Banner','sellnow' ),
		'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'sellnow' ),
		'panel'       		=> 'sellnow_front_page_panel',
	)
);

// Product content enable control and setting
$wp_customize->add_setting( 'sellnow_theme_options[hero_banner_section_enable]',
	array(
		'default'			=> 	$options['hero_banner_section_enable'],
		'sanitize_callback' => 'sellnow_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Sellnow_Switch_Control( $wp_customize,
	'sellnow_theme_options[hero_banner_section_enable]',
		array(
			'label'             => esc_html__( 'Hero Banner Section Enable', 'sellnow' ),
			'section'           => 'sellnow_hero_banner_section',
			'on_off_label' 		=> sellnow_switch_options(),
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[hero_banner_section_enable]', array(
        'selector'      => '#sellnow_hero_banner_section .tooltiptext',
        'settings'      => 'sellnow_theme_options[hero_banner_section_enable]',
    ) );
}

// Product content type control and setting
$wp_customize->add_setting( 'sellnow_theme_options[hero_banner_content_type]',
	array(
		'default'          	=> $options['hero_banner_content_type'],
		'sanitize_callback' => 'sellnow_sanitize_select',
	)
);

$wp_customize->add_control( 'sellnow_theme_options[hero_banner_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'sellnow' ),
		'section'           => 'sellnow_hero_banner_section',
		'type'				=> 'select',
		'active_callback' 	=> 'sellnow_is_hero_banner_section_enable',
		'choices'			=>  array(
			'product'            => esc_html__( 'Product', 'sellnow' ),
		)
	)
);

for( $i = 1 ; $i <= 3; $i++ ){

    $wp_customize->add_setting( 'sellnow_theme_options[hero_banner_content_product_' . $i . ']',
        array(
            'sanitize_callback' => 'sellnow_sanitize_page',
        )
    );

    $wp_customize->add_control( new Sellnow_Dropdown_Chooser( $wp_customize,
        'sellnow_theme_options[hero_banner_content_product_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Product %d', 'sellnow' ), $i ),
                'section'           => 'sellnow_hero_banner_section',
                'choices'           => sellnow_product_choices(),
                'active_callback'   => 'sellnow_is_hero_banner_section_enable',
            )
        )
    );

    // sellnow_Customize_Horizontal_Line
	$wp_customize->add_setting('sellnow_theme_options[hero_banner_separator'. $i .']',
        array(
            'sanitize_callback'      => 'sellnow_sanitize_html',
        )
    );

    $wp_customize->add_control(new Sellnow_Customize_Horizontal_Line($wp_customize,
        'sellnow_theme_options[hero_banner_separator'. $i .']',
            array(
                'type'                  => 'hr',
                'section'               => 'sellnow_hero_banner_section',
                'active_callback'       => 'sellnow_is_hero_banner_section_separator_enable'
            )
        )
    );

}

// featured product btn title setting and control
$wp_customize->add_setting( 'sellnow_theme_options[hero_banner_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['hero_banner_btn_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'sellnow_theme_options[hero_banner_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label', 'sellnow' ),
		'section'        	=> 'sellnow_hero_banner_section',
		'active_callback' 	=> 'sellnow_is_hero_banner_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[hero_banner_btn_title]',
		array(
			'selector'            => '#sellnow_hero_banner_section .product-content a.button',
			'settings'            => 'sellnow_theme_options[hero_banner_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'sellnow_hero_banner_section_btn_title_partial',
		)
	);
}

$wp_customize->add_setting( 'sellnow_theme_options[hero_banner_social]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new Sellnow_Multi_Input_Custom_Control( $wp_customize, 'sellnow_theme_options[hero_banner_social]', array(
	'label'             => esc_html__( 'Social Link', 'sellnow' ),
	'button_text'       => esc_html__( 'Add social', 'sellnow' ),
	'section'           => 'sellnow_hero_banner_section',
	'active_callback' 	=> 'sellnow_is_hero_banner_section_enable',
) ) );
