<?php
/**
 * Latest Products Section options
 *
 * @package Theme Palace
 * @subpackage Sellnow
 * @since Sellnow 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add lastest products section
$wp_customize->add_section( 'sellnow_latest_products_section', array(
    'title'             => esc_html__( 'Latest Products','sellnow' ),
    'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'sellnow' ),
    'panel'             => 'sellnow_front_page_panel',
) );

// lastest products content enable control and setting
$wp_customize->add_setting( 'sellnow_theme_options[latest_products_section_enable]', array(
    'default'           =>  $options['latest_products_section_enable'],
    'sanitize_callback' => 'sellnow_sanitize_switch_control',
) );

$wp_customize->add_control( new Sellnow_Switch_Control( $wp_customize, 'sellnow_theme_options[latest_products_section_enable]', array(
    'label'             => esc_html__( 'Latest Products Section Enable', 'sellnow' ),
    'section'           => 'sellnow_latest_products_section',
    'on_off_label'      => sellnow_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[latest_products_section_enable]', array(
        'selector'      => '#sellnow_latest_products_section .tooltiptext',
        'settings'      => 'sellnow_theme_options[latest_products_section_enable]',
    ) );
}

for ( $i=1; $i <= 2; $i++ ) {

    // Add dropdown category setting and control.
    $wp_customize->add_setting(  'sellnow_theme_options[latest_products_content_latest_products_category_'.$i.']', array(
        'sanitize_callback' => 'absint',
    ) ) ;

    $wp_customize->add_control( new Sellnow_Dropdown_Taxonomies_Control( $wp_customize,'sellnow_theme_options[latest_products_content_latest_products_category_'.$i.']', array(
        'label'             => sprintf( esc_html__( 'Select Latest Products Category %d', 'sellnow' ), $i ),
        'section'           => 'sellnow_latest_products_section',
        'taxonomy'          => 'product_cat',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'sellnow_is_latest_products_section_enable'
    ) ) );

    $wp_customize->add_setting( 'sellnow_theme_options[latest_products_description_'.$i.']', array(
        'sanitize_callback' => 'wp_kses_post',
    ) );

    $wp_customize->add_control( 'sellnow_theme_options[latest_products_description_'.$i.']', array(
        'label'             => esc_html__( 'Latest Product  Description ', 'sellnow' ).$i,
        'section'           => 'sellnow_latest_products_section',
        'active_callback'   => 'sellnow_is_latest_products_section_enable',
        'type'              => 'textarea',
    ) );

    $wp_customize->add_setting( 'sellnow_theme_options[latest_products_button_'.$i.']', array(
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( 'sellnow_theme_options[latest_products_button_'.$i.']', array(
        'label'             => esc_html__( 'Button Label ', 'sellnow' ).$i,
        'section'           => 'sellnow_latest_products_section',
        'active_callback'   => 'sellnow_is_latest_products_section_enable',
        'type'              => 'text',
    ) );
}