<?php
/**
 * Popular Collection Section options
 *
 * @package Theme Palace
 * @subpackage Sellnow
 * @since Sellnow 1.0.0
 */

// Add Product section
$wp_customize->add_section( 'sellnow_popular_collections_section',
	array(
		'title'             => esc_html__( 'Popular Collection','sellnow' ),
		'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'sellnow' ),
        'panel'       		=> 'sellnow_front_page_panel',
	)
);

// Product content enable control and setting
$wp_customize->add_setting( 'sellnow_theme_options[popular_collections_section_enable]',
	array(
		'default'			=> 	$options['popular_collections_section_enable'],
		'sanitize_callback' => 'sellnow_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Sellnow_Switch_Control( $wp_customize,
	'sellnow_theme_options[popular_collections_section_enable]',
		array(
			'label'             => esc_html__( 'Popular Collection Section Enable', 'sellnow' ),
			'section'           => 'sellnow_popular_collections_section',
			'on_off_label' 		=> sellnow_switch_options(),
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[popular_collections_section_enable]', array(
		'selector'            => '#sellnow_popular_collections_section .tooltiptext',
		'settings'            => 'sellnow_theme_options[popular_collections_section_enable]',
    ) );
}

// popular_collections title setting and control
$wp_customize->add_setting( 'sellnow_theme_options[popular_collections_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['popular_collections_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'sellnow_theme_options[popular_collections_title]',
	array(
		'label'           	=> esc_html__( 'Section Title', 'sellnow' ),
		'section'        	=> 'sellnow_popular_collections_section',
		'active_callback' 	=> 'sellnow_is_popular_collections_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[popular_collections_title]',
		array(
			'selector'            => '#sellnow_popular_collections_section .section-header h2.section-title',
			'settings'            => 'sellnow_theme_options[popular_collections_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'sellnow_popular_collections_section_title_partial',
		)
	);
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'sellnow_theme_options[popular_collections_content_product_category]',
	array(
		'sanitize_callback' => 'sellnow_sanitize_product_category_list',
		'validate_callback' => 'sellnow_pro_validate_popular_collection_product_cat_count',
	)
);

$wp_customize->add_control( new Sellnow_Dropdown_Multiple_Chooser( $wp_customize,
	'sellnow_theme_options[popular_collections_content_product_category]',
		array(
			'label'             => esc_html__( 'Select Product Category', 'sellnow' ),
			'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'sellnow' ),
			'section'           => 'sellnow_popular_collections_section',
			'choices'           =>  sellnow_product_category_choices(),
			'type'              => 'dropdown_multiple_chooser',
			'active_callback'	=> 'sellnow_is_popular_collections_section_enable'
		)
	)
);

// featured product btn title setting and control
$wp_customize->add_setting( 'sellnow_theme_options[popular_collections_buy_now_btn]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['popular_collections_buy_now_btn'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'sellnow_theme_options[popular_collections_buy_now_btn]',
    array(
        'label'             => esc_html__( 'Buy Now Button Label', 'sellnow' ),
        'section'           => 'sellnow_popular_collections_section',
        'active_callback'   => 'sellnow_is_popular_collections_section_enable',
        'type'              => 'text',
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[popular_collections_buy_now_btn]',
        array(
            'selector'            => '#sellnow_popular_collections_section li.product a.add_to_cart_button',
            'settings'            => 'sellnow_theme_options[popular_collections_buy_now_btn]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'sellnow_popular_collections_section_buy_now_btn_partial',
        )
    );
}


// featured product btn title setting and control
$wp_customize->add_setting( 'sellnow_theme_options[popular_collections_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['popular_collections_btn_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'sellnow_theme_options[popular_collections_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label ', 'sellnow' ),
		'section'        	=> 'sellnow_popular_collections_section',
		'active_callback' 	=> 'sellnow_is_popular_collections_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[popular_collections_btn_title]',
		array(
			'selector'            => '#sellnow_popular_collections_section div.read-more a',
			'settings'            => 'sellnow_theme_options[popular_collections_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'sellnow_popular_collections_section_btn_title_partial',
		)
	);
}

$wp_customize->add_setting( 'sellnow_theme_options[popular_collections_btn_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'sellnow_theme_options[popular_collections_btn_url]',
    array(
        'label'           	=> esc_html__( 'Button URL', 'sellnow' ),
        'section'        	=> 'sellnow_popular_collections_section',
        'active_callback' 	=> 'sellnow_is_popular_collections_section_enable',
        'type'				=> 'url',
    ) 
);