<?php
/**
* Recent Stories Section options
*
* @package Theme Palace
* @subpackage Sellnow
* @since Sellnow 1.0.0
*/

// Add Recent Stories Posts section
$wp_customize->add_section( 'sellnow_recent_stories_section', array(
	'title'             => esc_html__( 'Recent Stories','sellnow' ),
	'description'       => esc_html__( 'Recent Stories Section options.', 'sellnow' ),
	'panel'             => 'sellnow_front_page_panel',
) );

// Recent Stories Posts content enable control and setting
$wp_customize->add_setting( 'sellnow_theme_options[recent_stories_section_enable]', array(
	'default'			=> 	$options['recent_stories_section_enable'],
	'sanitize_callback' => 'sellnow_sanitize_switch_control',
	) );

$wp_customize->add_control( new Sellnow_Switch_Control( $wp_customize, 'sellnow_theme_options[recent_stories_section_enable]', array(
	'label'             => esc_html__( 'Recent Stories Posts Section Enable', 'sellnow' ),
	'section'           => 'sellnow_recent_stories_section',
	'on_off_label' 		=> sellnow_switch_options(),
	) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[recent_stories_section_enable]', array(
		'selector'      => '#sellnow_recent_stories_section .tooltiptext',
		'settings'      => 'sellnow_theme_options[recent_stories_section_enable]',
    ) );
}

// Recent Stories Posts title setting and control
$wp_customize->add_setting( 'sellnow_theme_options[recent_stories_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_stories_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'sellnow_theme_options[recent_stories_title]', array(
	'label'           	=> esc_html__( 'Title', 'sellnow' ),
	'section'        	=> 'sellnow_recent_stories_section',
	'active_callback' 	=> 'sellnow_is_recent_stories_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[recent_stories_title]', array(
		'selector'            => '#sellnow_recent_stories_section .section-header .section-title',
		'settings'            => 'sellnow_theme_options[recent_stories_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sellnow_recent_stories_section_title_partial',
		) );
}

for ( $i = 1; $i <= 3; $i++ ) :

// Recent Stories Posts posts drop down chooser control and setting
$wp_customize->add_setting( 'sellnow_theme_options[recent_stories_content_post_' . $i . ']', array(
	'sanitize_callback' => 'sellnow_sanitize_page',
	) );

$wp_customize->add_control( new Sellnow_Dropdown_Chooser( $wp_customize, 'sellnow_theme_options[recent_stories_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'sellnow' ), $i ),
	'section'           => 'sellnow_recent_stories_section',
	'choices'			=> sellnow_post_choices(),
	'active_callback'	=> 'sellnow_is_recent_stories_section_enable',
	) ) );
endfor;