<?php
/**
 * Subscribe Section options
 *
 * @package Theme Palace
 * @subpackage Sellnow
 * @since Sellnow 1.0.0
 */

// Subscribe section
$wp_customize->add_section('sellnow_subscribe_section',
    array(
        'title'         => esc_html__( 'Subscribe', 'sellnow' ),
        'description'   => sprintf( esc_html__( '%1$sJetpack%2$s should be active and site should be connected to WordPress.com for this section to work.', 'sellnow' ), '<a target="_blank" href="https://wordpress.org/plugins/jetpack">', '</a>' ),
        'panel'         => 'sellnow_front_page_panel',
    )
);

// Subscribe enable setting
$wp_customize->add_setting('sellnow_theme_options[subscribe_section_enable]',
    array(
        'sanitize_callback' => 'sellnow_sanitize_switch_control',
        'default'           => $options['subscribe_section_enable'],
    )
);

$wp_customize->add_control( new Sellnow_Switch_Control($wp_customize,
    'sellnow_theme_options[subscribe_section_enable]',
        array(
            'section'		=> 'sellnow_subscribe_section',
            'label'			=> esc_html__( 'Enable subscribe.', 'sellnow' ),
            'on_off_label'  => sellnow_switch_options(),
        )
    )
);

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[subscribe_section_enable]', array(
        'selector'            => '#biopexel_subscribe_section .tooltiptext',
        'settings'            => 'sellnow_theme_options[subscribe_section_enable]',
    ) );
}

// Subscribe Background image setting
$wp_customize->add_setting('sellnow_theme_options[subscribe_bg_image]',
    array(
        'sanitize_callback' => 'sellnow_sanitize_image',
    )
);

$wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize,
    'sellnow_theme_options[subscribe_bg_image]',
        array(
            'section'			=> 'sellnow_subscribe_section',
            'label'				=> esc_html__( 'Background Image:', 'sellnow' ),
            'active_callback' 	=> 'sellnow_is_subscribe_section_enable',
        )
    )
);

// Subscribe title setting
$wp_customize->add_setting('sellnow_theme_options[subscribe_section_subtitle]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscribe_section_subtitle'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('sellnow_theme_options[subscribe_section_subtitle]',
    array(
        'section'		    => 'sellnow_subscribe_section',
        'label'			    => esc_html__( 'Section Sub Title:', 'sellnow' ),
        'active_callback'   => 'sellnow_is_subscribe_section_enable',
        'type'              =>'text'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[subscribe_section_subtitle]',
		array(
			'selector'            => '#biopexel_subscribe_section .section-header p.section-subtitle',
			'settings'            => 'sellnow_theme_options[subscribe_section_subtitle]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'sellnow_subscribe_section_subtitle_partial',
		) 
	);
}

// Subscribe title setting
$wp_customize->add_setting('sellnow_theme_options[subscribe_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscribe_section_title'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('sellnow_theme_options[subscribe_section_title]',
    array(
        'section'		    => 'sellnow_subscribe_section',
        'label'			    => esc_html__( 'Section Title:', 'sellnow' ),
        'active_callback'   => 'sellnow_is_subscribe_section_enable',
        'type'              =>'text'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[subscribe_section_title]',
		array(
			'selector'            => '#biopexel_subscribe_section .section-header h2.section-title',
			'settings'            => 'sellnow_theme_options[subscribe_section_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'sellnow_subscribe_section_title_partial',
		) 
	);
}

// Subscribe title setting
$wp_customize->add_setting('sellnow_theme_options[subscribe_section_description]',
    array(
        'sanitize_callback' => 'wp_kses_post',
        'default'           => $options['subscribe_section_description'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('sellnow_theme_options[subscribe_section_description]',
    array(
        'section'		    => 'sellnow_subscribe_section',
        'label'			    => esc_html__( 'Section Description:', 'sellnow' ),
        'active_callback'   => 'sellnow_is_subscribe_section_enable',
        'type'              =>'textarea'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[subscribe_section_description]',
		array(
			'selector'            => '#biopexel_subscribe_section div.entry-content p',
			'settings'            => 'sellnow_theme_options[subscribe_section_description]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'sellnow_subscribe_section_description_partial',
		) 
	);
}

// Subscribe button text setting
$wp_customize->add_setting('sellnow_theme_options[subscribe_section_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscribe_section_btn_txt'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control('sellnow_theme_options[subscribe_section_btn_txt]',
    array(
        'section'		    => 'sellnow_subscribe_section',
        'label'			    => esc_html__( 'Button text:', 'sellnow' ),
        'active_callback'   => 'sellnow_is_subscribe_section_enable'
    )
);
    
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sellnow_theme_options[subscribe_section_btn_txt]',
        array(
            'selector'            => '#biopexel_subscribe_section #subscribe-submit button',
            'settings'            => 'sellnow_theme_options[subscribe_section_btn_txt]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'sellnow_subscribe_section_btn_txt_partial',
        ) 
    );
}