<?php
/**
 * Archive options
 *
 * @package Theme Palace
 * @subpackage  Sellnow
 * @since  Sellnow 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'sellnow_archive_section',
	array(
		'title'             => esc_html__( 'Blog/Archive','sellnow' ),
		'description'       => esc_html__( 'Archive section options.', 'sellnow' ),
		'panel'             => 'sellnow_theme_options_panel',
	)
);

// Your latest posts title setting and control.
$wp_customize->add_setting( 'sellnow_theme_options[your_latest_posts_title]',
	array(
		'default'           => $options['your_latest_posts_title'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control( 'sellnow_theme_options[your_latest_posts_title]',
	array(
		'label'             => esc_html__( 'Your Latest Posts Title', 'sellnow' ),
		'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'sellnow' ),
		'section'           => 'sellnow_archive_section',
		'type'				=> 'text',
		'active_callback'	=> function( $control ) {
			return !(
				sellnow_is_static_homepage_enable( $control )
			);
		}
	)
);

// features content type control and setting
$wp_customize->add_setting( 'sellnow_theme_options[blog_column]',
	array(
		'default'          	=> $options['blog_column'],
		'sanitize_callback' => 'sellnow_sanitize_select',
	)
);

$wp_customize->add_control( 'sellnow_theme_options[blog_column]',
	array(
		'label'             => esc_html__( 'Column Layout', 'sellnow' ),
		'section'           => 'sellnow_archive_section',
		'type'				=> 'select',
		'choices'			=> array( 
			'col-1'		=> esc_html__( 'One Column', 'sellnow' ),
			'col-2'		=> esc_html__( 'Two Column', 'sellnow' ),
			'col-3'		=> esc_html__( 'Three Column', 'sellnow' ),
		),
	)
);

// Archive tag category setting and control.
$wp_customize->add_setting( 'sellnow_theme_options[hide_category]',
	array(
		'default'           => $options['hide_category'],
		'sanitize_callback' => 'sellnow_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Sellnow_Switch_Control( $wp_customize,
	'sellnow_theme_options[hide_category]',
		array(
			'label'             => esc_html__( 'Hide Category', 'sellnow' ),
			'section'           => 'sellnow_archive_section',
			'on_off_label' 		=> sellnow_hide_options(),
		)
	)
);