<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage  Sellnow
 * @since  Sellnow 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function sellnow_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'sellnow' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function sellnow_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'sellnow' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function sellnow_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'sellnow' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function sellnow_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'sellnow' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function sellnow_product_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'product_cat',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'sellnow' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'sellnow_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function sellnow_site_layout() {
        $sellnow_site_layout = array(
            'wide'          => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'boxed-layout'  => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'sellnow_site_layout', $sellnow_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'sellnow_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function sellnow_selected_sidebar() {
        $sellnow_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'sellnow' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'sellnow' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'sellnow' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'sellnow' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'sellnow' ),
        );

        $output = apply_filters( 'sellnow_selected_sidebar', $sellnow_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'sellnow_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function sellnow_global_sidebar_position() {
        $sellnow_global_sidebar_position = array(
            'right-sidebar' => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar'    => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'sellnow_global_sidebar_position', $sellnow_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'sellnow_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function sellnow_sidebar_position() {
        $sellnow_sidebar_position = array(
            'right-sidebar'         => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar-content'    => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'sellnow_sidebar_position', $sellnow_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'sellnow_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function sellnow_pagination_options() {
        $sellnow_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'sellnow' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'sellnow' ),
        );

        $output = apply_filters( 'sellnow_pagination_options', $sellnow_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'sellnow_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function sellnow_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'sellnow' ),
            'off'       => esc_html__( 'Disable', 'sellnow' )
        );
        return apply_filters( 'sellnow_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'sellnow_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function sellnow_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'sellnow' ),
            'off'       => esc_html__( 'No', 'sellnow' )
        );
        return apply_filters( 'sellnow_hide_options', $arr );
    }
endif;