<?php
/**
 * Hero Banner section
 *
 * This is the template for the content of hero banner section
 *
 * @package Theme Palace
 * @subpackage Sellnow
 * @since Sellnow 1.0.0
 */
if ( ! function_exists( 'sellnow_add_hero_banner_section' ) ) :
    /**
    * Add hero_banner section
    *
    *@since Sellnow 1.0.0
    */
    function sellnow_add_hero_banner_section() {
    	$options = sellnow_get_theme_options();
        // Check if hero_banner is enabled on frontpage
        $hero_banner_enable = apply_filters( 'sellnow_section_status', true, 'hero_banner_section_enable' );

        if ( true !== $hero_banner_enable || !class_exists('WooCommerce')) {
            return false;
        }
        // Get hero_banner section details
        $section_details = array();
        $section_details = apply_filters( 'sellnow_filter_hero_banner_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render hero_banner section now.
        sellnow_render_hero_banner_section( $section_details );
    }
endif;

if ( ! function_exists( 'sellnow_get_hero_banner_section_details' ) ) :
    /**
    * hero_banner section details.
    *
    * @since Sellnow 1.0.0
    * @param array $input hero_banner section details.
    */
    function sellnow_get_hero_banner_section_details( $input ) {
        $options = sellnow_get_theme_options();

        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <= 3; $i++ ) {
            if ( ! empty( $options['hero_banner_content_product_' . $i] ) )
                $page_ids[] = $options['hero_banner_content_product_' . $i];
        }

        $args = array(
            'post_type'         => 'product',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( 3 ),
            'orderby'           => 'post__in',
        );

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = sellnow_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// hero_banner section content details.
add_filter( 'sellnow_filter_hero_banner_section_details', 'sellnow_get_hero_banner_section_details' );


if ( ! function_exists( 'sellnow_render_hero_banner_section' ) ) :
  /**
   * Start hero_banner section
   *
   * @return string hero_banner content
   * @since Sellnow 1.0.0
   *
   */
  function sellnow_render_hero_banner_section( $content_details = array() ) {
    $options = sellnow_get_theme_options();
    if ( empty( $content_details ) ) {
        return;
    }  ?>
    <style type="text/css">
      #sellnow_hero_banner_section {
        background-color: #f2f7f9;
        position: relative;
        z-index: 111;
        padding-top: 0;
    }
    #sellnow_hero_banner_section .hero-banner-content-wrapper {
        background-color: #fff;
        position: relative;
    }
    #sellnow_hero_banner_section .hero-banner-content-wrapper .featured-image img {
        width: 100% !important;
        object-fit: cover;
    }
    #sellnow_hero_banner_section .featured-image {
        position: relative;
        overflow: visible !important;
    }
    #sellnow_hero_banner_section h2.woocommerce-loop-product__title {
        font-weight: 600;
        font-family: 'Josefin Sans', sans-serif;
        font-size: 32px;
        color: #393d46;
    }
    #sellnow_hero_banner_section span.woocommerce-Price-amount.amount {
        font-weight: 600;
        font-family: 'Josefin Sans', sans-serif;
        font-size: 26px;
        color: #393d46;
    }
    #sellnow_hero_banner_section .entry-content p {
        font-weight: 400;
        font-family: 'Lato', sans-serif;
        font-size: 18px;
    }
    .woocommerce a.button {
        font-weight: 700;
        font-family: 'Josefin Sans', sans-serif;
        font-size: 16px;
        color: #393d46;
        border: 1px solid #cccccc;
        padding: 16px 40px;
    }
    a.dot {
        text-decoration: none;
        font-weight: 600;
        font-family: 'Josefin Sans', sans-serif;
        font-size: 32px;
        color: #393d46;
    }
    #sellnow_hero_banner_section .hero-banner-slider  .slick-dots li {
        height: auto;
        width: auto;
        display: block;
        position: relative;
        margin: 70px 0;
    }
    #sellnow_hero_banner_section .slick-dots {
        position: absolute;
        top: 10%;
        left: -47%;
    }
    #sellnow_hero_banner_section .slick-slider {
        position: unset;
    }
    #sellnow_hero_banner_section .slick-list {
        z-index: 1111;
    }
    #sellnow_hero_banner_section li:not(:last-child) a.dot:after {
        content: "";
        width: 1px;
        height: 50px;
        display: inline-block;
        background-color: #c6cbce;
        margin: 10px;
        position: absolute;
        top: 24px;
        left: 49.5%;
    }

    #sellnow_hero_banner_section .hero-banner-slider  .slick-dots li a {
        color: #c6cbce;
    }
    #sellnow_hero_banner_section .hero-banner-slider  .slick-dots li.slick-active a {
        color: #393d46;
    }
    #sellnow_hero_banner_section .hero-banner-slider  .slick-dots li.slick-active a.dot:after {
        background-color: #393d46;
    }
    #sellnow_hero_banner_section .product_meta {
        margin-bottom: 22px;
    }
    #sellnow_hero_banner_section a.button.product_type_simple.add_to_cart_button.ajax_add_to_cart {
        margin-top: 20px;
    }
    #sellnow_hero_banner_section .social-icons {
        float: left;
        position: absolute;
        bottom: 16%;
        left: 25px;
        display: none;
    }
    #sellnow_hero_banner_section .social-icons li {
        display: block;
    }
    #sellnow_hero_banner_section .social-icons svg {
        fill: #393d46;
    }
    #sellnow_hero_banner_section .social-icons a:hover svg,
    #sellnow_hero_banner_section .social-icons a:focus svg {
        fill: #fff;
    }
    #sellnow_hero_banner_section .hero-banner-slider .slick-dots li a {
        display: none;
    }
    #sellnow_hero_banner_section .product-content {
        padding: 60px;
    }
    #sellnow_hero_banner_section h2.woocommerce-loop-product__title {
        margin-bottom: 5px;
    }
    #sellnow_hero_banner_section .slider-number {
        position: absolute;
        top: 10%;
        right: 24%;
    }
    #sellnow_hero_banner_section .slider-number span {
        font-weight: 700;
        font-family: 'Josefin Sans', sans-serif;
        font-size: 100px;
        display: none;
    }
    #sellnow_hero_banner_section h2.woocommerce-loop-product__title:hover,
    #sellnow_hero_banner_section h2.woocommerce-loop-product__title:focus,
    #sellnow_trending_section h2.woocommerce-loop-product__title:hover,
    #sellnow_trending_section h2.woocommerce-loop-product__title:focus,
    #sellnow_services_section p a:hover,
    #sellnow_services_section p a:focus {
        color: #000;
    }

    #sellnow_hero_banner_section .slider-number span {
        background-repeat: repeat;
        -webkit-background-clip: text;
        -webkit-text-fill-color: transparent;
        text-align: center;
        -webkit-font-smoothing: antialiased;
        padding: 55px 0;
        background-size: cover;
        background-position: 50%;
    }


    @media screen and (min-width: 767px) {
        #sellnow_hero_banner_section .hero-banner-slider .slick-dots li a {
            display: block;
        }
    }

    @media screen and (min-width: 1025px) {
        #sellnow_hero_banner_section .social-icons {
            display: block;
        }
    }

    @media screen and (min-width: 1200px) {
        #sellnow_hero_banner_section .slider-number span {
            font-size: 150px;
        }
        #sellnow_hero_banner_section .hero-banner-content-wrapper {
            display: table;
            position: relative;
            align-items: center;
            width: 100%;
        }
        #sellnow_hero_banner_section .product-content {
            width: 33.33%;
            text-align: unset;
            display: table-cell;
            text-align: unset;
            float: right;
            padding: 200px 35px 20px;
        }
        #sellnow_hero_banner_section .featured-image {
            width: 66.67%;
            position: absolute;
            display: table-cell;
            bottom: 0;
            left: 0;
            top: 0;
            padding-bottom: 0;
            margin-bottom: 0;
        }
        #sellnow_hero_banner_section .slider-number span {
            display: block;
        }
    }

    @media screen and (min-width: 1900px) {
        #sellnow_hero_banner_section h2.woocommerce-loop-product__title {
            font-size: 50px
        }
        #sellnow_hero_banner_section span.woocommerce-Price-amount.amount {
            font-size: 32px;
        }
        #sellnow_hero_banner_section .entry-content p {
            font-size: 22px;
        }
        #sellnow_hero_banner_section .product-content {
            padding: 280px 45px 65px;
        }
        #sellnow_hero_banner_section .slick-dots {
            left: -45%;
        }
        #sellnow_hero_banner_section .social-icons {
            bottom: 12%;
            left: 4%;
        }
        #sellnow_hero_banner_section .social-icons li {
            margin-bottom: 20px;
        }
        #sellnow_hero_banner_section .slider-number span {
            font-size: 199.92px;
            padding: 80px 0;
        }
        #sellnow_hero_banner_section .featured-image img {
            width: 1500px;
            max-height: 930px;
            object-fit: cover;
        }
    }
</style>
<div id="sellnow_hero_banner_section" class="page-section relative">
    <div class="wrapper">
        <?php if ( is_customize_preview()):
            sellnow_section_tooltip( 'sellnow_hero_banner_section' );
        endif; ?>
        <div class="hero-banner-slider products" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": false, "draggable": true, "fade": true, "adaptiveHeight": true }'>
            <?php foreach ( $content_details as $i=>$content ): $product = new WC_Product( $content['id'] );  ?>
                <article>
                    <div class="hero-banner-content-wrapper clear">
                        <div class="featured-image">
                            <img src="<?php echo esc_url( $content['image'] ); ?>">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link" tabindex="-1">
                            </a>
                        </div>
                        <div class="slider-number">
                            <span style="background-image:url('<?php echo esc_url($content['image']); ?>');"><?php if ( $i < 10 ) echo '0' ?><?php echo $i+1; ?></span>
                        </div>
                        <div class="product-content">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link" tabindex="0">
                                <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </a>
                            <span class="price"><?php echo $product->get_price_html(); ?></span>
                            <div class="product_meta">
                                <a href="#" class="woocommerce-LoopProduct-link woocommerce-loop-product__link" tabindex="0">
                                </a>
                            </div><!-- .product-meta -->
                            <a href="#" class="woocommerce-LoopProduct-link woocommerce-loop-product__link" tabindex="0">
                                <span class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </span>
                            </a>
                            <a href="<?php echo do_shortcode( '[add_to_cart_url id="' .absint( $product->get_id() ). '"]' ); ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php echo esc_html($options['hero_banner_btn_title']); ?>
                            </a>
                            </div>
                        </div>
                    </article>
                <?php endforeach; ?>
            </div><!-- .section-content -->
            <div class="social-icons">
                <ul>
                    <?php 
                    $hero_banner_socials = ! empty( $options['hero_banner_social'] ) ? explode( '|', $options['hero_banner_social'] ) : array(); 

                    foreach ( $hero_banner_socials as $hero_banner_social ) : 

                        ?>
                        <li>
                            <a href="<?php echo esc_url( $hero_banner_social ); ?>"><?php echo sellnow_return_social_icon( $hero_banner_social ); ?></a>
                        </li>
                    <?php endforeach; ?>
                </ul><!-- .social-icons -->
            </div><!-- .social-icons -->
        </div><!-- .wrapper -->
    </div><!-- #blogmax_hero_banner_section -->
<?php }
endif;     