<?php
/**
 * latest products section
 *
 * This is the template for the content of latest products section
 *
 * @package Theme Palace
 * @subpackage Fairtimes Pro
 * @since Fairtimes Pro 1.0.0
 */
if ( ! function_exists( 'sellnow_add_latest_products_section' ) ) :
    /**
    * Add latest products section
    *
    *@since Fairtimes Pro 1.0.0
    */
    function sellnow_add_latest_products_section() {
        $options = sellnow_get_theme_options();
        // Check if latest products is enabled on frontpage
        $latest_products_enable = apply_filters( 'sellnow_section_status', true, 'latest_products_section_enable' );

        if ( ( true !== $latest_products_enable) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }

        // Render latest products section now.
        sellnow_render_latest_products_section();
    }
endif;

if ( ! function_exists( 'sellnow_render_latest_products_section' ) ) :
  /**
   * Start latest products section
   *
   * @return string latest products content
   * @since Fairtimes Pro 1.0.0
   *
   */
  function sellnow_render_latest_products_section() {
    $options = sellnow_get_theme_options();

    ?>

    <div id="sellnow_latest_products_section" class="page-section same-background relative">
        <div class="wrapper">
        <?php if ( is_customize_preview()):
            sellnow_section_tooltip( 'sellnow_latest_products_section' );
        endif; ?>
            <div class="section-content col-2">
                <?php for ( $i=1; $i <= 2; $i++ ) { 
                    if ( empty($options['latest_products_content_latest_products_category_'.$i]) ) {
                        continue;
                    }
                    $thumbnail_id = get_term_meta( $options['latest_products_content_latest_products_category_'.$i], 'thumbnail_id', true );
                    $image = !empty( wp_get_attachment_url( $thumbnail_id ) ) ? wp_get_attachment_url( $thumbnail_id ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';
                    $cat_name = get_term_by( 'id', $options['latest_products_content_latest_products_category_'.$i], 'product_cat' )->name;
                    $cat_link = get_category_link( $options['latest_products_content_latest_products_category_'.$i] );
                    $product_description = empty( $options['latest_products_description_'.$i] ) ? '' : $options['latest_products_description_'.$i];
                    $shop_now_btn = empty( $options['latest_products_button_'.$i] ) ? '' : $options['latest_products_button_'.$i];
                    ?>
                    <article>
                        <div class="latest-products-wrapper">
                            <div class="entry-container">
                                <div class="entry-header">
                                    <h2 class="entry-title">
                                        <a href="<?php echo esc_url( $cat_link ); ?>"><?php echo esc_html( $cat_name ); ?></a>
                                    </h2>
                                </div>
                                <div class="entry-content">
                                    <p><?php echo esc_html( $product_description ); ?></p>
                                </div>
                                <?php if( !empty( $shop_now_btn ) ): ?>
                                    <div class="shop-now">
                                        <a href="<?php echo esc_url( $cat_link ); ?>" class="btn"><?php echo esc_html( $shop_now_btn ); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            </div>

                            <div class="featured-image hero-match-height" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                            </div>
                        </div>
                    </article>
               <?php } ?>

           </div><!-- .grid --> 
       </div><!-- .wrapper -->
   </div>

<?php }
endif;