<?php
/**
 * Popular Collections section
 *
 * This is the template for the content of popular_collections section
 *
 * @package Theme Palace
 * @subpackage Sellnow
 * @since Sellnow 1.0.0
 */
if ( ! function_exists( 'sellnow_add_popular_collections_section' ) ) :
    /**
    * Add popular_collections section
    *
    *@since Sellnow 1.0.0
    */
    function sellnow_add_popular_collections_section() {
    	$options = sellnow_get_theme_options();
        // Check if popular_collections is enabled on frontpage
        $popular_collections_enable = apply_filters( 'sellnow_section_status', true, 'popular_collections_section_enable' );

        if ( true !== $popular_collections_enable) {
            return false;
        }
        // Get popular_collections section details
        $section_details = array();
        $section_details = apply_filters( 'sellnow_filter_popular_collections_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_collections section now.
        sellnow_render_popular_collections_section( $section_details );
    }
endif;

if ( ! function_exists( 'sellnow_get_popular_collections_section_details' ) ) :
    /**
    * popular_collections section details.
    *
    * @since Sellnow 1.0.0
    * @param array $input popular_collections section details.
    */
    function sellnow_get_popular_collections_section_details( $input ) {
        $options = sellnow_get_theme_options();

        $args = array();
        $cat_ids = ! empty( $options['popular_collections_content_product_category'] ) ? $options['popular_collections_content_product_category'] : array();

        if ( empty( $cat_ids ) )
            return;

        foreach ( $cat_ids as $cat_id ) :

            $category_args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( 3 ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            array_push( $args, $category_args );
        endforeach;                  


        $i = 0;
        $content = array();
        foreach ( $args as $arg ) :

            // Run The Loop.
            $query = new WP_Query( $arg );
            if ( $query->have_posts() ) : 
                $details = [];
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = sellnow_trim_content( 20 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $details, $page_post );
                endwhile;
                $cat_id = $arg['tax_query'][0]['terms'];
                array_push( $content, array('cat_id'=> $cat_id, 'details'=> $details) );
            endif;
            wp_reset_postdata();
            $i++;
        endforeach;

    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_collections section content details.
add_filter( 'sellnow_filter_popular_collections_section_details', 'sellnow_get_popular_collections_section_details' );


if ( ! function_exists( 'sellnow_render_popular_collections_section' ) ) :
  /**
   * Start popular_collections section
   *
   * @return string popular_collections content
   * @since Sellnow 1.0.0
   *
   */
   function sellnow_render_popular_collections_section( $content_details = array() ) {
    $options = sellnow_get_theme_options();
    $popular_collections_btn_url = (!empty($options['popular_collections_btn_url'])) ? $options['popular_collections_btn_url'] : '';

    if ( empty( $content_details ) ) {
        return;
    }  ?>

        <div id="sellnow_popular_collections_section" class="page-section relative">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    sellnow_section_tooltip( 'sellnow_popular_collections_section' );
                endif; ?>
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['popular_collections_title'] ); ?></h2>
                </div><!-- .section-header --> 
                
                <div class="section-content">
                    <div class="product-filtering">
                        <ul class="product-nav">
                            <?php foreach ( $content_details as $i=>$content ): $terms = get_term( $content['cat_id'] ); ?>
                                <li <?php if($i==0) echo 'class="active"'; ?>><a href="#" data-tab="<?php echo $terms->slug; ?>"><?php echo $terms->name; ?></a></li>
                            <?php endforeach; ?>
                        </ul>
                    </div><!-- .product-filtering -->

                    <div class="product-wrapper">
                        
                    <?php foreach ( $content_details as $i=>$contents ): $terms = get_term( $contents['cat_id'] ); ?>
                        <div id="<?php echo $terms->slug; ?>" class="tab-content <?php if($i==0) echo 'active'; ?> clear">  
                            <ul class="products col-3 container">
                                <?php foreach ( $contents['details'] as $content ):
                                    if(class_exists('WooCommerce') ) $popular_collections = new WC_Product( $content['id'] ); ?>
                                <li class="product featured-products ">
                                    <a href="<?php echo esc_url($content['url'] ); ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                         <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
                                            <div class="overlay"></div>
                                        </div>
                                        <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    </a>
                                    <?php if(class_exists('WooCommerce')) : ?>
                                    <div class="product_meta"><a href="<?php echo esc_url($content['url'] ); ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                            <span class="price"><?php echo $popular_collections->get_price_html(); ?></span>
                                    </div><!-- .product-meta -->
                                    <div class="product-button">
                                        <?php if(!empty($options['popular_collections_buy_now_btn']) ) : ?>
                                            <div class="buy-now">
                                                <a href="<?php echo esc_url($content['url'] ); ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php echo esc_html( $options['popular_collections_buy_now_btn']); ?></a>
                                            </div>
                                        <?php endif; ?>
                                        <div class="favourite">
                                            <?php if(class_exists('YITH_WCWL')) echo do_shortcode( '[yith_wcwl_add_to_wishlist product_id='.$content['id'].']' ); ?>
                                        </div>
                                        <div class="cart-icon">
                                            <a href="<?php echo do_shortcode( '[add_to_cart_url id="' .absint( $popular_collections->get_id() ). '"]' ); ?>" class="product_type_simple add_to_cart_button ajax_add_to_cart">
                                                <?php echo sellnow_get_svg( array( 'icon' => 'cart-popular-collection' ) ); ?>
                                            </a>
                                        </div>
                                    </div>
                                    <?php endif; ?>
                                </li>
                                <?php endforeach; ?>
                            </ul>
                        </div><!-- .tab-content -->
                    <?php endforeach; ?>

                    </div><!-- .product-wrapper -->
                    <?php if(!empty($options['popular_collections_btn_title']) && !empty($popular_collections_btn_url)): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url($popular_collections_btn_url); ?>" class="btn"><?php echo esc_html( $options['popular_collections_btn_title'] ); ?></a>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div><!-- #product-->

    <?php }
endif;     