<?php
/**
 * Recent Stories Section
 *
 * This is the template for the content of Recent Stories section
 *
 * @package Theme Palace
 * @subpackage Sellnow
 * @since Sellnow 1.0.0
 */
if ( ! function_exists( 'sellnow_add_recent_stories_section' ) ) :
    /**
    * Add Recent Stories section
    *
    *@since Sellnow 1.0.0
    */
    function sellnow_add_recent_stories_section() {
        $options = sellnow_get_theme_options();
        // Check if Recent Stories is enabled on frontpage
        $recent_stories_enable = apply_filters( 'sellnow_section_status', true, 'recent_stories_section_enable' );

        if ( true !== $recent_stories_enable ) {
            return false;
        }
        // Get Recent Stories section details
        $section_details = array();
        $section_details = apply_filters( 'sellnow_filter_recent_stories_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Recent Stories section now.
        sellnow_render_recent_stories_section( $section_details );
    }
endif;

if ( ! function_exists( 'sellnow_get_recent_stories_section_details' ) ) :
    /**
    * Recent Stories section details.
    *
    * @since Sellnow 1.0.0
    * @param array $input Recent Stories section details.
    */
    function sellnow_get_recent_stories_section_details( $input ) {
        $options = sellnow_get_theme_options();
        
        $content  = array();
        $post_ids = array();

        for ( $i = 1; $i <= 3; $i++ ) {
            if ( ! empty( $options['recent_stories_content_post_' . $i] ) )
                $post_ids[] = $options['recent_stories_content_post_' . $i];
        }
        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( 3 ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
        );                    



            // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['auth_id']   = get_the_author_meta('ID');
                $page_post['title']     = get_the_title();
                $page_post['content']   = get_the_content();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Recent Stories section content details.
add_filter( 'sellnow_filter_recent_stories_section_details', 'sellnow_get_recent_stories_section_details' );


if ( ! function_exists( 'sellnow_render_recent_stories_section' ) ) :
  /**
   * Start Recent Stories section
   *
   * @return string Recent Stories content
   * @since Sellnow 1.0.0
   *
   */
  function sellnow_render_recent_stories_section( $content_details = array() ) {
    $options = sellnow_get_theme_options();
    $title = ! empty( $options['recent_stories_title'] ) ? $options['recent_stories_title'] : '';

    if ( empty( $content_details ) ) {
        return;
    } ?>

    <div id="sellnow_recent_stories_section" class="page-section same-background relative">
        <div class="wrapper">
            <?php if ( is_customize_preview()):
                sellnow_section_tooltip( 'sellnow_recent_stories_section' );
            endif; ?>
            <div class="section-header">
                <?php if( !empty( $title ) ): ?>
                    <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
                <?php endif; ?>
            </div><!-- .section-header -->

            <div class="section-content col-3">
                <?php foreach ( $content_details as $content ) : ?>
                    <article>
                        <div class="recent-stories-post-wrapper">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <div class="date">
                                    <span class="day"><?php echo get_the_date('n', $content['id']); ?></span>
                                    <span class="month"><?php echo get_the_date('M', $content['id']); ?></span>
                                </div>
                            </div>

                            <div class="entry-container">
                                <div class="entry-meta">
                                    <span class="cat-links">
                                       <?php the_category( '', '', $content['id'] ); ?>
                                   </span><!-- .cat-links -->
                               </div><!-- .entry-meta -->

                               <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                        </div>
                    </div>
                </article>
            <?php endforeach; ?>

        </div><!-- .section-contentr -->
    </div><!-- .wrapper -->
</div><!-- #sellnow_recent_stories_section_section -->

<?php }
endif;