<?php
/**
 * Subscribe section
 *
 * This is the template for the content of subscribe section
 *
 * @package Theme Palace
 * @subpackage Biopexel Pro
 * @since Biopexel Pro 1.0.0
 */
if ( ! function_exists( 'sellnow_add_subscribe_section' ) ) :
    /**
    * Add subscribe section
    *
    *@since Biopexel Pro 1.0.0
    */
    function sellnow_add_subscribe_section() {
        $options = sellnow_get_theme_options();
        if ( ! class_exists( 'Jetpack' ) ) {
            return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
                return;
        }

        // Check if subscribe is enabled on frontpage
        $subscribe_enable = apply_filters( 'sellnow_section_status', true, 'subscribe_section_enable' );

        if ( true !== $subscribe_enable ) {
            return false;
        }
        // Render subscribe section now.
        sellnow_render_subscribe_section();
    }
endif;

if ( ! function_exists( 'sellnow_render_subscribe_section' ) ) :
  /**
   * Start subscribe section
   *
   * @return string subscribe content
   * @since Biopexel Pro 1.0.0
   *
   */
   function sellnow_render_subscribe_section() {
        $options = sellnow_get_theme_options();
        $subscribe_btn_title   = ! empty( $options['subscribe_section_btn_txt'] ) ? $options['subscribe_section_btn_txt'] : esc_html__( 'Submit Now', 'sellnow' );
        $subscribe_bg_image = !empty($options['subscribe_bg_image']) ? $options['subscribe_bg_image'] : ''; 
    ?>


        <div id="sellnow_subscribe_section" class="relative page-section same-background">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                  sellnow_section_tooltip( 'sellnow_subscribe_section' );
                endif; ?>
                <article style="background-image: url('<?php echo esc_url( $subscribe_bg_image ); ?>');">
                    <div class="overlay"></div>
                    <div class="subscribe-post-wrapper">
                        <div class="entry-container">
                            <div class="section-header">
                                <?php if ( !empty( $options['subscribe_section_subtitle'] ) ) : ?>
                                    <p class="section-subtitle"><?php echo esc_html( $options['subscribe_section_subtitle'] ); ?></p>
                                <?php endif; ?>
                                <?php if ( !empty( $options['subscribe_section_title'] ) ) : ?>
                                    <h2 class="section-title"><?php echo esc_html( $options['subscribe_section_title'] ); ?></h2>
                                <?php endif; ?>
                            </div><!-- .section-header -->
                            <div class="entry-content">
                                <p><?php echo esc_html( $options['subscribe_section_description'] ); ?></p>
                            </div><!-- .entry-content -->
                            <div class="subscribe-form-wrapper">
                                <?php 
                                $subscribe_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html( $subscribe_btn_title ) . '" show_subscribers_total="0"]';
                                echo do_shortcode( wp_kses_post( $subscribe_shortcode ) );
                                ?>
                            </div>
                        </div><!-- .entry-container -->
                    </div>
                </article>
            </div><!-- .wrapper -->
        </div><!-- #blogmax_subscribe_section -->    
        
    <?php
    }
endif; ?>
