<?php
/**
 * Why Choose Us section
 *
 * This is the template for the content of why_choose_us section
 *
 * @package Theme Palace
 * @subpackage Sellnow
 * @since Sellnow 1.0.0
 */
if ( ! function_exists( 'sellnow_add_why_choose_us_section' ) ) :
    /**
    * Add why_choose_us section
    *
    *@since Sellnow 1.0.0
    */
    function sellnow_add_why_choose_us_section() {
        $options = sellnow_get_theme_options();
        // Check if why_choose_us is enabled on frontpage
        $why_choose_us_enable = apply_filters( 'sellnow_section_status', true, 'why_choose_us_section_enable' );

        if ( true !== $why_choose_us_enable ) {
            return false;
        }
        // Get why_choose_us section details
        $section_details = array();
        $section_details = apply_filters( 'sellnow_filter_why_choose_us_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render why_choose_us section now.
        sellnow_render_why_choose_us_section( $section_details );
    }
endif;

if ( ! function_exists( 'sellnow_get_why_choose_us_section_details' ) ) :
    /**
    * why_choose_us section details.
    *
    * @since Sellnow 1.0.0
    * @param array $input why_choose_us section details.
    */
    function sellnow_get_why_choose_us_section_details( $input ) {
        $options = sellnow_get_theme_options();
        
        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <= 3; $i++ ) {
            if ( ! empty( $options['why_choose_us_content_page_' . $i] ) )
                $page_ids[] = $options['why_choose_us_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => 3,
            'orderby'           => 'post__in',
        );                    

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = sellnow_trim_content( 30 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// why_choose_us section content details.
add_filter( 'sellnow_filter_why_choose_us_section_details', 'sellnow_get_why_choose_us_section_details' );


if ( ! function_exists( 'sellnow_render_why_choose_us_section' ) ) :
  /**
   * Start why_choose_us section
   *
   * @return string why_choose_us content
   * @since Sellnow 1.0.0
   *
   */
   function sellnow_render_why_choose_us_section( $content_details = array() ) {
        $options = sellnow_get_theme_options();
        $i = 1;        

        if ( empty( $content_details ) ) {
            return;
        } 
    ?>
        
        <div id="sellnow_why_choose_us_section" class="page-section relative">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    sellnow_section_tooltip( 'sellnow_why_choose_us_section' );
                endif; ?>
                <div class="section-header">
                    <?php if ( $options['why_choose_us_title']) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['why_choose_us_title'] ); ?></h2>
                    <?php endif; ?>
                </div><!-- .section-header -->
                <div class="section-content col-3">
                    <?php foreach ( $content_details as $i => $content ) : ?>
                        <article>
                            <div class="why-us-wrapper">
                                <div class="entry-container">
                                    <div class="entry-content-wrapper">
                                        <div class="icon-container">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>">
                                                <i class="fa <?php echo ! empty( $options['why_choose_us_content_icon_' . ($i+1)] ) ? esc_attr( $options['why_choose_us_content_icon_' . ($i+1)] ) : 'fa-cogs'; ?>"></i>
                                            </a>
                                        </div><!-- .why_choose_us-icon -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                        <?php if( !empty( $options['why_choose_us_btn_title']) ) : ?>
                                            <div class="read-more">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['why_choose_us_btn_title'] ); ?><i class="fa fa-plus"></i></a>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                </div><!-- .entry-container -->
                            </div><!-- .why_choose_us-item -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #sellnow_why_choose_us_section_section -->
        
    <?php }
endif;