<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage  Sellnow
 * @since  Sellnow 1.0.0
 */

$options = sellnow_get_theme_options();  


if ( ! function_exists( 'sellnow_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since  Sellnow 1.0.0
	 */
	function sellnow_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;
add_action( 'sellnow_doctype', 'sellnow_doctype', 10 );


if ( ! function_exists( 'sellnow_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since  Sellnow 1.0.0
	 *
	 */
	function sellnow_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php endif;
	}
endif;
add_action( 'sellnow_before_wp_head', 'sellnow_head', 10 );

if ( ! function_exists( 'sellnow_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since  Sellnow 1.0.0
	 *
	 */
	function sellnow_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'sellnow' ); ?></a>
		<?php
	}
endif;
add_action( 'sellnow_page_start_action', 'sellnow_page_start', 10 );

if ( ! function_exists( 'sellnow_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since  Sellnow 1.0.0
	 *
	 */
	function sellnow_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'sellnow_page_end_action', 'sellnow_page_end', 10 );

if ( ! function_exists( 'sellnow_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since  Sellnow 1.0.0
	 *
	 */
	function sellnow_site_branding() {
		$options  = sellnow_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];	 ?>
		<div id="topbar" class="relative">
			<div id="drop-button">
				<svg viewBox="0 0 284.929 284.929" class="dropdown-icon icon-up">
					<path d="M282.082,195.285L149.028,62.24c-1.901-1.903-4.088-2.856-6.562-2.856s-4.665,0.953-6.567,2.856L2.856,195.285C0.95,197.191,0,199.378,0,201.853c0,2.474,0.953,4.664,2.856,6.566l14.272,14.271c1.903,1.903,4.093,2.854,6.567,2.854c2.474,0,4.664-0.951,6.567-2.854l112.204-112.202l112.208,112.209c1.902,1.903,4.093,2.848,6.563,2.848c2.478,0,4.668-0.951,6.57-2.848l14.274-14.277c1.902-1.902,2.847-4.093,2.847-6.566C284.929,199.378,283.984,197.188,282.082,195.285z"></path>
				</svg>
				<svg viewBox="0 0 129 129" class="dropdown-icon icon-down">
					<path d="m121.3,34.6c-1.6-1.6-4.2-1.6-5.8,0l-51,51.1-51.1-51.1c-1.6-1.6-4.2-1.6-5.8,0-1.6,1.6-1.6,4.2 0,5.8l53.9,53.9c0.8,0.8 1.8,1.2 2.9,1.2 1,0 2.1-0.4 2.9-1.2l53.9-53.9c1.7-1.6 1.7-4.2 0.1-5.8z"></path>
				</svg>
			</div>
			
			<div class="wrapper">
				<div class="section-content col-3">
					<div class="cart hentry">
					<?php

						if( class_exists('WooCommerce') ){

							$cart_button = sprintf(
								'<li class="cart-icon"><a href="%1$s">%2$s</a></li>',
								wc_get_cart_url(),
								sellnow_get_svg( array( 'icon' => 'cart' ) ),
							);
						}else{
							$cart_button = '';
						}

						$search_html = sprintf(
							'<ul><li class="search-menu"><a href="#" title="%1$s">%2$s</a><div id="search"></div></li>' . $cart_button . '</ul>',
							esc_attr__('Search','sellnow'),
							get_search_form( $echo = false ),

						);

						echo $search_html;
					?>

					</div>
					<?php
					$login_button = null;
					$login_url = !empty( $options['login_url'] ) ? $options['login_url'] : '#';
					if($options['enable_login_button'] && !empty($options['login_text'] && $login_url) ) :
						$login_button = sprintf(
							'<div class="login-button hentry"><a href="' . $login_url . '" class="custom-button">%1$s</a></div>',
							esc_html( $options['login_text']),
						);
						echo $login_button;
					endif;
					?>
				</div>
			</div>
		</div>
		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
				<div class="site-branding-container clear">
					<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false" title="Primary Menu">
						<?php
						echo sellnow_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
						echo sellnow_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
						?>	
						<span class="menu-label"><?php esc_html_e('Menu', 'sellnow')?></span>		
					</button>
				
					<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
						<?php
							wp_nav_menu( array(
								'theme_location' => 'primary',
								'container' => 'ul',
								'menu_class' => 'menu nav-menu',
								'menu_id' => 'primary-menu',
								'echo' => true,
								'fallback_cb' => 'sellnow_menu_fallback_cb',
								'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>',
							) );
								
						?>
					</nav><!-- #site-navigation -->
					<div class="site-branding-wrapper">
						<div class="site-branding">
							<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) ) && has_custom_logo()  ) : ?>
							<div class="site-logo">
								<?php the_custom_logo(); ?>
							</div>
						<?php endif; 

						if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
							<div id="site-identity">
								<?php
								if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
									if ( sellnow_is_latest_posts() ) : ?>
										<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
										<?php else : ?>
											<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
											<?php
										endif;
									} 
									if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
										$description = get_bloginfo( 'description', 'display' );
										if ( $description || is_customize_preview() ) : ?>
											<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
											<?php
										endif; 
									}?>
								</div>
							<?php endif; ?>
						</div>
					</div><!-- .site-branding-wrapper -->
					<div class="cart">
						<?php
						$login_button = null;
						$login_url = !empty( $options['login_url'] ) ? $options['login_url'] : '';
						if( $options['enable_login_button'] && !empty( $options['login_text'] && $login_url ) ) :
						$login_button = sprintf(
							'<li class="login-button"><a href="' . $login_url . '" class="custom-button">%1$s</a></li>',
							esc_html( $options['login_text']),
						);
						endif;

						if(class_exists('WooCommerce')){

							$cart_button = sprintf(
								'<li class="cart-icon"><a href="%1$s">%2$s</a></li>',
								wc_get_cart_url(),
								sellnow_get_svg( array( 'icon' => 'cart' ) ),
							);
						}else{
							$cart_button = '';
						}

						$search_html = sprintf(
							'<ul><li class="search-menu"><a href="#" title="%1$s">%2$s%3$s</a><div id="search">%4$s</div></li>' . $cart_button . $login_button . '</ul>',
							esc_attr__('Search','sellnow'),
							sellnow_get_svg( array( 'icon' => 'search' ) ), 
							sellnow_get_svg( array( 'icon' => 'close' ) ), 
							get_search_form( $echo = false ),

						);
					
						echo $search_html;
						?>
           
                    </div>
				</div><!-- .site-branding-wrapper-container clear -->
			</div>
		</header><!-- .header-->
	<?php 
	}
endif;
add_action( 'sellnow_header_action', 'sellnow_site_branding', 10 );

if ( ! function_exists( 'sellnow_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Sellnow 1.0.0
	 *
	 */
	function sellnow_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'sellnow_content_start_action', 'sellnow_content_start', 10 );

if ( ! function_exists( 'sellnow_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since  Sellnow 1.0.0
     *
     */
    function sellnow_header_image() {
    	if ( sellnow_is_frontpage() )
    		return;
    	$header_image = get_header_image();
    	if ( is_singular() ) :
    		$header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
    	endif;
    	?>

    	<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
    		<div class="overlay"></div>
    		<div class="wrapper">
    			<header class="page-header">
    				<?php sellnow_custom_header_banner_title(); ?>
    			</header>
    			<?php sellnow_add_breadcrumb(); ?>
    		</div>
    	</div><!-- #page-site-header -->

    	<?php
    }
endif;
add_action( 'sellnow_header_image_action', 'sellnow_header_image', 10 );

if ( ! function_exists( 'sellnow_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since  Sellnow 1.0.0
	 */
	function sellnow_add_breadcrumb() {
		$options = sellnow_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( sellnow_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * sellnow_simple_breadcrumb hook
				 *
				 * @hooked sellnow_simple_breadcrumb -  10
				 *
				 */
				do_action( 'sellnow_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'sellnow_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Sellnow 1.0.0
	 *
	 */
	function sellnow_content_end() {
		?>
        </div><!-- #content -->
		<?php
	}
endif;
add_action( 'sellnow_content_end_action', 'sellnow_content_end', 10 );

if ( ! function_exists( 'sellnow_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Sellnow 1.0.0
	 *
	 */
	function sellnow_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'sellnow_footer', 'sellnow_footer_start', 10 );

if ( ! function_exists( 'sellnow_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Sellnow 1.0.0
	 *
	 */
	function sellnow_footer_site_info() {
		$options = sellnow_get_theme_options();
		$theme_data = wp_get_theme();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text'];
		?>
		<div class="site-info clear col-2">
			<div class="wrapper">
				<?php if ( !empty( $options['footer_background_image']) ) : ?>
					<div class="site-branding-wrapper">
						<div class="site-branding">
							<div class="site-logo">
								<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $options['footer_background_image'] ); ?>" alt="Logo"></a>
							</div>
						</div><!-- .site-branding -->
					</div><!-- .site-branding-wrapper -->
				<?php endif; ?>
				<div class="copyright-text">
					<p>
						<?php
						echo sellnow_santize_allow_tag( $copyright_text ); 
						echo esc_html__( ' All Rights Reserved | ', 'sellnow' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'sellnow' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>';
						?>
					</p>
				
				</div>
			</div><!-- .wrapper -->    
		</div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'sellnow_footer', 'sellnow_footer_site_info', 40 );

if ( ! function_exists( 'sellnow_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Sellnow 1.0.0
	 *
	 */
	function sellnow_footer_scroll_to_top() {
		$options  = sellnow_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo sellnow_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'sellnow_footer', 'sellnow_footer_scroll_to_top', 40 );


